# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.

<!-- scriv-insert-here -->

<a id='changelog-2025.3.17'></a>
## [2025.3.17] - 2025-03-17

- Support for Python 3.13

<a id='changelog-2025.2.27'></a>
## [2025.2.27] - 2025-02-27

### Changed

- Add a migration to swap in `BigAutoField` for the `filewatchrenewalattempt`, `googleapiauth`, and `googlefilewatch` models.

### removed

- support for python 3.8 and 3.9.

### added

<a id='changelog-2025.2.4'></a>
## [2025.2.4] - 2025-02-04

### Changed

- Update paths in pyproject.toml to ensure versioning continues to work.

- Removes unnecessary noqa's.

- Bumped Google Python API package versions

<a id='changelog-2024.7.3'></a>
## [2024.7.3] - 2024-07-03

### Changed

- Updated README with instructions for setup.

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

- Added posthog application.

<a id='changelog-2023.12.19.1'></a>
## [2023.12.19.1] - 2023-12-19

### Changed

- Updated README with instructions for setup.

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

<a id='changelog-2023.12.19'></a>
## [2023.12.19] - 2023-12-19

### Changed

- Updated README with instructions for setup.

- Updated requirements and lockfiles to support Django 4.
- Removed support for Django 2.2.

## [0.1.0] - 2022-06-22

### Added
- Added `mitol.google_sheets` core Google Sheets library.
- Added the `mitol-django-google-sheets` app
